@@ -4,6 +4,6 @@ exec_cmd('ada2wsdl',
          ['-q', '-f', '-Pwsdl_8_main',
           '-a', 'http://localhost:7708', 'wsdl_8.ads', '-o', 'wsdl_8.wsdl'])
 exec_cmd('wsdl2aws',
-         ['-q', '-f', '-sp', '-cb', '-types', 'wsdl_8', 'wsdl_8.wsdl'])
+         ['-q', '-f', '-cb', '-types', 'wsdl_8', 'wsdl_8.wsdl'])
 
 build_and_run('wsdl_8_main');
